@@ -10,7 +10,7 @@ lgreen = '\033[92m'
 clear = '\033[0m'
 bold = '\033[01m'
 cyan = '\033[96m'
-version = "1.1.7"
+version = "1.1.9"
 global log
 global anon
 anon = "tor"
@@ -385,7 +385,7 @@ class inquiry:
             except:
                  timeo.cancel()
                  try:
-                     ip = "6.tcp.eu.ngrok.io"
+                     ip = "3.66.38.117"
                      port = "10882"
                      proxy = ip+":"+port
                      if log:
@@ -494,7 +494,7 @@ class inquiry:
             except:
                  timeo.cancel()
                  try:
-                     ip = "6.tcp.eu.ngrok.io"
+                     ip = "3.66.38.117"
                      port = "10882"
                      proxy = ip+":"+port
                      if log:
@@ -582,11 +582,9 @@ class inquiry:
             except:
                  timeo.cancel()
                  try:
-                     proxy_list = pyproxify.fetch(count=2, google=True, https=True)
-                     for item in proxy_list:
-                         ip = item["ip"]
-                         port = item["port"]
-                         proxy = ip+":"+port
+                     ip = "3.66.38.117"
+                     port = "10882"
+                     proxy = ip+":"+port
                      if log:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
@@ -594,9 +592,7 @@ class inquiry:
                      with eventlet.Timeout(10) as timeoo:
                          with requests.Session() as ss:
                              ss.proxies.update(proxies)
-                             args = " ".join([str(m) for m in args])
-                             url = args.replace("https", "http")
-                             put = ss.put(url, **kwargs, headers={"User-Agent": ua.windows()})
+                             put = ss.put(args, **kwargs, headers={"User-Agent": ua.windows()})
                              if log:
                                  print("[100%] Success")
                              return put
@@ -674,11 +670,9 @@ class inquiry:
             except:
                  timeo.cancel()
                  try:
-                     proxy_list = pyproxify.fetch(count=2, google=True, https=True)
-                     for item in proxy_list:
-                         ip = item["ip"]
-                         port = item["port"]
-                         proxy = ip+":"+port
+                     ip = "3.66.38.117"
+                     port = "10882"
+                     proxy = ip+":"+port
                      if log:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
@@ -686,9 +680,7 @@ class inquiry:
                      with eventlet.Timeout(10) as timeoo:
                          with requests.Session() as ss:
                              ss.proxies.update(proxies)
-                             args = " ".join([str(m) for m in args])
-                             url = args.replace("https", "http")
-                             delete = ss.delete(url, **kwargs, headers={"User-Agent": ua.windows()})
+                             delete = ss.delete(args, **kwargs, headers={"User-Agent": ua.windows()})
                              if log:
                                  print("[100%] Success")
                              return delete
@@ -766,11 +758,9 @@ class inquiry:
             except:
                  timeo.cancel()
                  try:
-                     proxy_list = pyproxify.fetch(count=2, google=True, https=True)
-                     for item in proxy_list:
-                         ip = item["ip"]
-                         port = item["port"]
-                         proxy = ip+":"+port
+                     ip = "3.66.38.117"
+                     port = "10882"
+                     proxy = ip+":"+port
                      if log:
                          print("[92%] Failed using other proxy")
                          print("[95%] Proxy: "+ip+":"+port)
@@ -778,12 +768,10 @@ class inquiry:
                      with eventlet.Timeout(10) as timeoo:
                          with requests.Session() as ss:
                              ss.proxies.update(proxies)
-                             args = " ".join([str(m) for m in args])
-                             url = args.replace("https", "http")
-                             head = ss.head(url, **kwargs, headers={"User-Agent": ua.windows()})
+                             delete = ss.delete(args, **kwargs, headers={"User-Agent": ua.windows()})
                              if log:
                                  print("[100%] Success")
-                             return head
+                             return delete
                  except:
                      return '\033[91m403 Website refused to connect\x1B[37m'
     def debug():
